@@ -32,13 +32,28 @@ class YamcsReSTRenderer(ReSTRenderer):
 
 
 def create_service_file(symbol, service, filename):
+    methods = []
+    for method in service.method:
+        route_options = method.options.Extensions[annotations_pb2.route]
+        if route_options.deprecated:
+            continue
+
+        ws_options = method.options.Extensions[annotations_pb2.websocket]
+        if ws_options.deprecated:
+            continue
+
+        methods.append(method)
+
     context = {
         "symbol": symbol,
         "service": service,
+        "methods": methods,
     }
+
     text = YamcsReSTRenderer().render_string(templates.service, context)
     with FileAvoidWrite(filename) as f:
         f.write(text)
+        f.write("\n")
 
 
 def create_route_file(symbol, method, filename, has_related):
@@ -51,6 +66,7 @@ def create_route_file(symbol, method, filename, has_related):
     text = YamcsReSTRenderer().render_string(templates.route, context)
     with FileAvoidWrite(filename) as f:
         f.write(text)
+        f.write("\n")
 
 
 def create_websocket_file(symbol, method, filename, has_related):
@@ -63,6 +79,7 @@ def create_websocket_file(symbol, method, filename, has_related):
     text = YamcsReSTRenderer().render_string(templates.websocket, context)
     with FileAvoidWrite(filename) as f:
         f.write(text)
+        f.write("\n")
 
 
 def generate(parser, destdir, title, additional_docs):
@@ -87,6 +104,14 @@ def generate(parser, destdir, title, additional_docs):
                 service_links.append(servicedir.name + "/index")
 
                 for method in service.method:
+                    route_options = method.options.Extensions[annotations_pb2.route]
+                    if route_options.deprecated:
+                        continue
+
+                    ws_options = method.options.Extensions[annotations_pb2.websocket]
+                    if ws_options.deprecated:
+                        continue
+
                     filename = camel_to_slug(method.name) + ".rst"
                     methodfile = os.path.join(servicedir, filename)
                     symbol = "." + file.package + "." + service.name + "." + method.name
@@ -100,6 +125,14 @@ def generate(parser, destdir, title, additional_docs):
                         create_websocket_file(symbol, method, methodfile, has_related)
             else:
                 for method in service.method:
+                    route_options = method.options.Extensions[annotations_pb2.route]
+                    if route_options.deprecated:
+                        continue
+
+                    ws_options = method.options.Extensions[annotations_pb2.websocket]
+                    if ws_options.deprecated:
+                        continue
+
                     filename = camel_to_slug(method.name) + ".rst"
                     methodfile = Path(destdir, filename)
                     symbol = "." + file.package + "." + service.name + "." + method.name
@@ -128,6 +161,7 @@ def generate(parser, destdir, title, additional_docs):
     indexfile = os.path.join(destdir, "index.rst")
     with FileAvoidWrite(indexfile) as f:
         f.write(text)
+        f.write("\n")
     generated_files.append("index.rst")
 
     with Path(destdir, ".autogen").open("w") as f:
